# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# CAM签名/鉴权错误。
AUTHFAILURE = 'AuthFailure'

# 操作失败。
FAILEDOPERATION = 'FailedOperation'

# 内部错误。
INTERNALERROR = 'InternalError'

# 内部服务调用异常。
INTERNALERROR_ACCOUNTCGWERROR = 'InternalError.AccountCgwError'

# 内部服务调用异常。
INTERNALERROR_CAMCGWERROR = 'InternalError.CamCgwError'

# 内部服务调用异常。
INTERNALERROR_CAMERROR = 'InternalError.CamError'

# 内部服务调用异常。
INTERNALERROR_CBSCGWERROR = 'InternalError.CbsCgwError'

# 内部服务调用异常。
INTERNALERROR_CBSERROR = 'InternalError.CbsError'

# 内部服务调用异常。
INTERNALERROR_CDBCGWERROR = 'InternalError.CdbCgwError'

# 内部服务调用异常。
INTERNALERROR_CDBERROR = 'InternalError.CdbError'

# 内部服务调用异常。
INTERNALERROR_CONFIGCGWERROR = 'InternalError.ConfigCgwError'

# 内部服务调用异常。
INTERNALERROR_CVMERROR = 'InternalError.CvmError'

# 内部服务调用异常。
INTERNALERROR_KMSERROR = 'InternalError.KmsError'

# 内部服务调用异常。
INTERNALERROR_PROJECTCGWERROR = 'InternalError.ProjectCgwError'

# 安全组接口调用异常。
INTERNALERROR_SGERROR = 'InternalError.SgError'

# 内部服务调用异常。
INTERNALERROR_TAGERROR = 'InternalError.TagError'

# 内部服务调用异常。
INTERNALERROR_TRADECGWERROR = 'InternalError.TradeCgwError'

# 内部服务调用异常。
INTERNALERROR_VPCCGWERROR = 'InternalError.VpcCgwError'

# 内部服务调用异常。
INTERNALERROR_VPCERROR = 'InternalError.VpcError'

# 内部服务调用异常。
INTERNALERROR_WOODSERVERERROR = 'InternalError.WoodServerError'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 无效参数，AppId。
INVALIDPARAMETER_INVALIDAPPID = 'InvalidParameter.InvalidAppId'

# 无效参数，ClusterId。
INVALIDPARAMETER_INVALIDCLUSTERID = 'InvalidParameter.InvalidClusterId'

# 无效的集群名称。
INVALIDPARAMETER_INVALIDINSTANCENAME = 'InvalidParameter.InvalidInstanceName'

# 无效的NodeType。
INVALIDPARAMETER_INVALIDNODETYPE = 'InvalidParameter.InvalidNodeType'

# 无法找到该实例。
RESOURCENOTFOUND_CLUSTERNOTFOUND = 'ResourceNotFound.ClusterNotFound'

# 无法找到该实例。
RESOURCENOTFOUND_INSTANCENOTFOUND = 'ResourceNotFound.InstanceNotFound'

# KeyTab文件上传中，请稍等片刻。
RESOURCENOTFOUND_KEYTABFILENOTREADY = 'ResourceNotFound.KeyTabFileNotReady'

# 无法找到服务组件配置。
RESOURCENOTFOUND_SERVICECONFNOTFOUND = 'ResourceNotFound.ServiceConfNotFound'

# 无法找到该服务组件。
RESOURCENOTFOUND_SERVICEGROUPNOTFOUND = 'ResourceNotFound.ServiceGroupNotFound'

# 操作不支持。
UNSUPPORTEDOPERATION = 'UnsupportedOperation'

# 该服务不支持此操作。
UNSUPPORTEDOPERATION_SERVICENOTSUPPORT = 'UnsupportedOperation.ServiceNotSupport'
